@@ -1,6 +1,7 @@
-from axe_core_python.sync_playwright import Axe
 from playwright.sync_api import sync_playwright
 
+from axe_playwright_python.sync_playwright import Axe
+
 axe = Axe()
 
 with sync_playwright() as playwright:
