@@ -36,6 +36,13 @@ def webkit_page():
         browser.close()
 
 
+def _perform_axe_run(page):
+    page.goto("file://" + str(TEST_FILE_PATH))
+    axe = Axe()
+    results = axe.run(page=page)
+    return results.response
+
+
 def test_run_axe_sample_page_firefox(firefox_page):
     """Run axe against sample page and verify JSON output is as expected."""
     data = _perform_axe_run(firefox_page)
@@ -66,8 +73,18 @@ def test_run_axe_sample_page_webkit(webkit_page):
     assert len(data["violations"]) == 9
 
 
-def _perform_axe_run(page):
-    page.goto("file://" + str(TEST_FILE_PATH))
+def test_run_axe_detects_region_violation(chromium_page):
+    """Baseline check confirming region violation is reported by default."""
+    chromium_page.goto("file://" + str(TEST_FILE_PATH))
     axe = Axe()
-    results = axe.run(page=page)
-    return results.response
+
+    # First run with default options
+    results = axe.run(page=chromium_page)
+    violation_ids = {violation["id"] for violation in results.response["violations"]}
+    assert "region" in violation_ids
+
+    # Now run again with region rule disabled
+    options = {"rules": {"region": {"enabled": False}}}
+    results = axe.run(page=chromium_page, options=options)
+    violation_ids = {violation["id"] for violation in results.response["violations"]}
+    assert "region" not in violation_ids
